/* Copyright (c) 2014 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 * @defgroup pin_change_int_example_main main.c
 * @{
 * @ingroup pin_change_int_example
 * @brief Pin Change Interrupt Example Application main file.
 *
 * This file contains the source code for a sample application using interrupts triggered by GPIO pins.
 *
 */
#include <stdbool.h>
#include "nrf.h"
#include "nrf_drv_gpiote.h"
#include "app_error.h"
#include "boards.h"
//#include "nrf_drv_ppi.h"

#ifdef BSP_BUTTON_0
    #define PIN_IN BSP_BUTTON_0
#endif
#ifndef PIN_IN
    #error "Please indicate input pin"
#endif

#ifdef BSP_LED_0
    #define PIN_OUT BSP_LED_0
#endif
#ifndef PIN_OUT
    #error "Please indicate output pin"
#endif


//
#ifdef BSP_BUTTON_1
    #define PIN_IN1 BSP_BUTTON_1
#endif
#ifndef PIN_IN1
    #error "Please indicate input pin"
#endif

#ifdef BSP_LED_1
    #define PIN_OUT1 BSP_LED_1
#endif
#ifndef PIN_OUT1
    #error "Please indicate output pin"
#endif
void in_pin_handler(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action)
{
	nrf_drv_gpiote_in_is_set(PIN_OUT);
}

void in_pin_handler1(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action)
{
    nrf_drv_gpiote_out_toggle(PIN_OUT1);
}

/*
 * @brief Function for configuring: PIN_IN pin for input, PIN_OUT pin for output,
 * and configures GPIOTE to give an interrupt on pin change.
 */
static void gpio_init(void)
{
    ret_code_t err_code;

    err_code = nrf_drv_gpiote_init();
    APP_ERROR_CHECK(err_code);

    nrf_drv_gpiote_out_config_t out_config = GPIOTE_CONFIG_OUT_SIMPLE(false);

    err_code = nrf_drv_gpiote_out_init(PIN_OUT, &out_config);
    APP_ERROR_CHECK(err_code);

    nrf_drv_gpiote_in_config_t in_config = GPIOTE_CONFIG_IN_SENSE_TOGGLE(true);
    in_config.pull = NRF_GPIO_PIN_PULLUP;

    err_code = nrf_drv_gpiote_in_init(PIN_IN, &in_config, in_pin_handler);
    APP_ERROR_CHECK(err_code);

    nrf_drv_gpiote_in_event_enable(PIN_IN, true);
}
/*
 * @brief Function for application main entry.
 */

	static void gpio1_init(void)
	{
		ret_code_t err_code1;

		err_code1 = nrf_drv_gpiote_init();
		APP_ERROR_CHECK(err_code1);

		nrf_drv_gpiote_out_config_t out_config1 = GPIOTE_CONFIG_OUT_SIMPLE(false);

		err_code1= nrf_drv_gpiote_out_init(PIN_OUT1, &out_config1);
		APP_ERROR_CHECK(err_code1);

		nrf_drv_gpiote_in_config_t in = GPIOTE_CONFIG_IN_SENSE_TOGGLE(true);
		in.pull = NRF_GPIO_PIN_PULLUP;

		err_code1 = nrf_drv_gpiote_in_init(PIN_IN1, &in, in_pin_handler1);
	    APP_ERROR_CHECK(err_code1);

	    nrf_drv_gpiote_in_event_enable(PIN_IN1, true);
	}

int main(void)
{
    gpio_init();
    gpio1_init();
    while (true)
    {
        // Do nothing.
    }
}

/* @} */
